'''
Created by auto_sdk on 2020.04.30
'''
from libs.customize.top.api.base import RestApi
class MiniappTemplateOnlineappRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.app_id = None
		self.app_version = None
		self.clients = None
		self.template_id = None
		self.template_version = None

	def getapiname(self):
		return 'taobao.miniapp.template.onlineapp'



from libs.customize.top.api.rest.OpenuidGetBytradeRequest import OpenuidGetBytradeRequest
from libs.customize.top.api.rest.ItemsCustomGetRequest import ItemsCustomGetRequest
from libs.customize.top.api.rest.AlibabaAliqinTaNumberSinglecallbyttsRequest import AlibabaAliqinTaNumberSinglecallbyttsRequest
from libs.customize.top.api.rest.AlibabaAliqinTaSmsNumQueryRequest import AlibabaAliqinTaSmsNumQueryRequest
from libs.customize.top.api.rest.MiniappItemsGetRequest import MiniappItemsGetRequest
from libs.customize.top.api.rest.AlibabaAliqinTaSmsNumSendRequest import AlibabaAliqinTaSmsNumSendRequest
from libs.customize.top.api.rest.TopAuthTokenCreateRequest import TopAuthTokenCreateRequest
from libs.customize.top.api.rest.VasSubscribeGetRequest import VasSubscribeGetRequest
from libs.customize.top.api.rest.MiniapppTemplateInstantiateRequest import MiniapppTemplateInstantiateRequest
from libs.customize.top.api.rest.SellercenterRoleAddRequest import SellercenterRoleAddRequest
from libs.customize.top.api.rest.OpenuidGetRequest import OpenuidGetRequest
from libs.customize.top.api.rest.ShopcatsListGetRequest import ShopcatsListGetRequest
from libs.customize.top.api.rest.SellercenterRolemembersGetRequest import SellercenterRolemembersGetRequest
from libs.customize.top.api.rest.SubuserInfoUpdateRequest import SubuserInfoUpdateRequest
from libs.customize.top.api.rest.SellercatsListGetRequest import SellercatsListGetRequest
from libs.customize.top.api.rest.OpenlinkSessionGetRequest import OpenlinkSessionGetRequest
from libs.customize.top.api.rest.ShopSellerGetRequest import ShopSellerGetRequest
from libs.customize.top.api.rest.SubuserDepartmentsGetRequest import SubuserDepartmentsGetRequest
from libs.customize.top.api.rest.AppstoreSubscribeGetRequest import AppstoreSubscribeGetRequest
from libs.customize.top.api.rest.OpenuidGetBymixnickRequest import OpenuidGetBymixnickRequest
from libs.customize.top.api.rest.AppipGetRequest import AppipGetRequest
from libs.customize.top.api.rest.TopSecretGetRequest import TopSecretGetRequest
from libs.customize.top.api.rest.SubuserEmployeeAddRequest import SubuserEmployeeAddRequest
from libs.customize.top.api.rest.FuwuScoresGetRequest import FuwuScoresGetRequest
from libs.customize.top.api.rest.ItemSkuGetRequest import ItemSkuGetRequest
from libs.customize.top.api.rest.TmcUserCancelRequest import TmcUserCancelRequest
from libs.customize.top.api.rest.TopIpoutGetRequest import TopIpoutGetRequest
from libs.customize.top.api.rest.SubusersGetRequest import SubusersGetRequest
from libs.customize.top.api.rest.ItemcatsGetRequest import ItemcatsGetRequest
from libs.customize.top.api.rest.TopSecretRegisterRequest import TopSecretRegisterRequest
from libs.customize.top.api.rest.HttpdnsGetRequest import HttpdnsGetRequest
from libs.customize.top.api.rest.TmcTopicGroupAddRequest import TmcTopicGroupAddRequest
from libs.customize.top.api.rest.TmcTopicGroupDeleteRequest import TmcTopicGroupDeleteRequest
from libs.customize.top.api.rest.ItemSkusGetRequest import ItemSkusGetRequest
from libs.customize.top.api.rest.ItempropvaluesGetRequest import ItempropvaluesGetRequest
from libs.customize.top.api.rest.SellercenterUserPermissionsGetRequest import SellercenterUserPermissionsGetRequest
from libs.customize.top.api.rest.ItemsOnsaleGetRequest import ItemsOnsaleGetRequest
from libs.customize.top.api.rest.MiniappUserInfoGetRequest import MiniappUserInfoGetRequest
from libs.customize.top.api.rest.AlibabaAliqinTaVoiceNumDoublecallRequest import AlibabaAliqinTaVoiceNumDoublecallRequest
from libs.customize.top.api.rest.OpenTradeGetRequest import OpenTradeGetRequest
from libs.customize.top.api.rest.MiniappTemplateOnlineappRequest import MiniappTemplateOnlineappRequest
from libs.customize.top.api.rest.ItemsInventoryGetRequest import ItemsInventoryGetRequest
from libs.customize.top.api.rest.TmcMessagesConfirmRequest import TmcMessagesConfirmRequest
from libs.customize.top.api.rest.MiniappTemplateUpdateappRequest import MiniappTemplateUpdateappRequest
from libs.customize.top.api.rest.TopSdkFeedbackUploadRequest import TopSdkFeedbackUploadRequest
from libs.customize.top.api.rest.TmcGroupsGetRequest import TmcGroupsGetRequest
from libs.customize.top.api.rest.ItempropsGetRequest import ItempropsGetRequest
from libs.customize.top.api.rest.MiniappTemplateUpdateRequest import MiniappTemplateUpdateRequest
from libs.customize.top.api.rest.FuwuSaleLinkGenRequest import FuwuSaleLinkGenRequest
from libs.customize.top.api.rest.SellercenterRoleInfoGetRequest import SellercenterRoleInfoGetRequest
from libs.customize.top.api.rest.TimeGetRequest import TimeGetRequest
from libs.customize.top.api.rest.SellercenterSubuserPermissionsRolesGetRequest import SellercenterSubuserPermissionsRolesGetRequest
from libs.customize.top.api.rest.SubuserDutysGetRequest import SubuserDutysGetRequest
from libs.customize.top.api.rest.AlibabaAliqinTaNumberSinglecallbyvoiceRequest import AlibabaAliqinTaNumberSinglecallbyvoiceRequest
from libs.customize.top.api.rest.OpenTradesSoldGetRequest import OpenTradesSoldGetRequest
from libs.customize.top.api.rest.ItemSellerGetRequest import ItemSellerGetRequest
from libs.customize.top.api.rest.KfcKeywordSearchRequest import KfcKeywordSearchRequest
from libs.customize.top.api.rest.MiniappTemplateInstantiateRequest import MiniappTemplateInstantiateRequest
from libs.customize.top.api.rest.SellercenterRolesGetRequest import SellercenterRolesGetRequest
from libs.customize.top.api.rest.OpenuidChangeRequest import OpenuidChangeRequest
from libs.customize.top.api.rest.TopAuthTokenRefreshRequest import TopAuthTokenRefreshRequest
from libs.customize.top.api.rest.SellercenterSubusersGetRequest import SellercenterSubusersGetRequest
from libs.customize.top.api.rest.MiniappTemplateQueryappRequest import MiniappTemplateQueryappRequest
from libs.customize.top.api.rest.TmcMessagesProduceRequest import TmcMessagesProduceRequest
from libs.customize.top.api.rest.TmcUserPermitRequest import TmcUserPermitRequest
from libs.customize.top.api.rest.TmcMessagesConsumeRequest import TmcMessagesConsumeRequest
from libs.customize.top.api.rest.UserSellerGetRequest import UserSellerGetRequest
from libs.customize.top.api.rest.SubuserFullinfoGetRequest import SubuserFullinfoGetRequest
from libs.customize.top.api.rest.TmcMessageProduceRequest import TmcMessageProduceRequest
from libs.customize.top.api.rest.ItemcatsAuthorizeGetRequest import ItemcatsAuthorizeGetRequest
from libs.customize.top.api.rest.TmcAuthGetRequest import TmcAuthGetRequest
from libs.customize.top.api.rest.SkusCustomGetRequest import SkusCustomGetRequest
from libs.customize.top.api.rest.FilesGetRequest import FilesGetRequest
from libs.customize.top.api.rest.VasOrderSearchRequest import VasOrderSearchRequest
from libs.customize.top.api.rest.TmcGroupAddRequest import TmcGroupAddRequest
from libs.customize.top.api.rest.TmcUserGetRequest import TmcUserGetRequest
from libs.customize.top.api.rest.ItemsSellerListGetRequest import ItemsSellerListGetRequest
from libs.customize.top.api.rest.VasSubscSearchRequest import VasSubscSearchRequest
from libs.customize.top.api.rest.TmcGroupDeleteRequest import TmcGroupDeleteRequest
